==> haskell-hxt-charproperties-9.4.0.0-4-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hxt-charproperties.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 hxt-charproperties
version:              9.4.0.0
visibility:           public
id:                   hxt-charproperties-9.4.0.0-8jDCsoIbVFKAUm5I1yRNPq
key:                  hxt-charproperties-9.4.0.0-8jDCsoIbVFKAUm5I1yRNPq
license:              MIT
copyright:            Copyright (c) 2010- Uwe Schmidt
maintainer:           Uwe Schmidt <uwe@fh-wedel.de>
author:               Uwe Schmidt
stability:            Stable
homepage:             https://github.com/UweSchmidt/hxt
synopsis:             Character properties and classes for XML and Unicode
description:
    Character properties defined by XML and Unicode standards.
    These modules contain predicates for Unicode blocks and char proprties
    and character predicates defined by XML.
    Supported Unicode version is 12.1.0
    9.3.0.2: Supported Unicode version 9.0.0

category:             Text
abi:                  eea89d4d27d74ce093f4f21971763495
exposed:              True
exposed-modules:
    Data.Char.Properties.UnicodeBlocks
    Data.Char.Properties.UnicodeCharProps
    Data.Char.Properties.XMLCharProps Data.Set.CharSet

import-dirs:          /usr/lib/ghc-8.8.3/site-local/hxt-charproperties-9.4.0.0
library-dirs:         /usr/lib/ghc-8.8.3/site-local/hxt-charproperties-9.4.0.0
dynamic-library-dirs: /usr/lib
data-dir:
    /usr/share/x86_64-linux-ghc-8.8.3/hxt-charproperties-9.4.0.0

hs-libraries:         HShxt-charproperties-9.4.0.0-8jDCsoIbVFKAUm5I1yRNPq
depends:              base-4.13.0.0
haddock-interfaces:
    /usr/share/doc/haskell-hxt-charproperties/html/hxt-charproperties.haddock

haddock-html:         /usr/share/doc/haskell-hxt-charproperties/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hxt-charproperties-9.4.0.0-5-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hxt-charproperties.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 hxt-charproperties
version:              9.4.0.0
visibility:           public
id:                   hxt-charproperties-9.4.0.0-8WBrTGDxJMv51F9pnJvmFg
key:                  hxt-charproperties-9.4.0.0-8WBrTGDxJMv51F9pnJvmFg
license:              MIT
copyright:            Copyright (c) 2010- Uwe Schmidt
maintainer:           Uwe Schmidt <uwe@fh-wedel.de>
author:               Uwe Schmidt
stability:            Stable
homepage:             https://github.com/UweSchmidt/hxt
synopsis:             Character properties and classes for XML and Unicode
description:
    Character properties defined by XML and Unicode standards.
    These modules contain predicates for Unicode blocks and char proprties
    and character predicates defined by XML.
    Supported Unicode version is 12.1.0
    9.3.0.2: Supported Unicode version 9.0.0

category:             Text
abi:                  dcefceb5fe685d8517edad626c8d4d4d
exposed:              True
exposed-modules:
    Data.Char.Properties.UnicodeBlocks
    Data.Char.Properties.UnicodeCharProps
    Data.Char.Properties.XMLCharProps Data.Set.CharSet

import-dirs:          /usr/lib/ghc-8.10.1/site-local/hxt-charproperties-9.4.0.0
library-dirs:         /usr/lib/ghc-8.10.1/site-local/hxt-charproperties-9.4.0.0
dynamic-library-dirs: /usr/lib
data-dir:
    /usr/share/x86_64-linux-ghc-8.10.1/hxt-charproperties-9.4.0.0

hs-libraries:         HShxt-charproperties-9.4.0.0-8WBrTGDxJMv51F9pnJvmFg
depends:              base-4.14.0.0
haddock-interfaces:
    /usr/share/doc/haskell-hxt-charproperties/html/hxt-charproperties.haddock

haddock-html:         /usr/share/doc/haskell-hxt-charproperties/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
